using System;
using Greg.XmlEditor.Presentation.Presenters;

namespace Greg.XmlEditor.Presentation.Commands.Concrete
{
	public class SaveAsCommand : CommandBase
	{
		private readonly MasterPresenter presenter;
		private readonly IInteractionManager interaction;

		public SaveAsCommand(MasterPresenter presenter, IInteractionManager interaction)
		{
			this.presenter = presenter;
			this.interaction = interaction;
		}

		/// <summary>
		/// Refreshes the command state.
		/// </summary>
		public override void Refresh()
		{
			this.IsEnabled = (this.presenter.CurrentDocument != null);
		}

		/// <summary>
		/// Executes the command logics.
		/// </summary>
		public override void Invoke()
		{
			try
			{
				var document = this.presenter.CurrentDocument;

				var fileName = document.FullPath;
				if (!this.interaction.AskWhereToSaveFile(ref fileName)) return;

				document.Save(fileName);
			}
			catch (Exception ex)
			{
				this.interaction.ShowError(ex.Message);
			}
		}
	}
}